@@ -172,7 +172,7 @@ def episode_calculation(
             episode_data_df = subject_episode_data
         else:
             episode_data_df = pd.concat([episode_data_df, subject_episode_data], ignore_index=True)
-        
+
         if episode_summary_df.empty:
             episode_summary_df = subject_summary
         else:
@@ -245,7 +245,8 @@ def episode_single(
             day_one = day_one.tz_convert(local_tz)
         ndays = len(gd2d_tuple[1])
         # generate grid times by starting from day one and cumulatively summing
-        time_ip =  pd.date_range(start=day_one + pd.Timedelta(minutes=dt0), periods=int(ndays * 24 * 60 /dt0), freq=f"{dt0}min")
+        time_ip =  pd.date_range(start=day_one + pd.Timedelta(minutes=dt0), periods=int(ndays * 24 * 60 /dt0),
+                                 freq=f"{dt0}min")
         data_ip = gd2d_tuple[0].flatten().tolist()
         new_data = pd.DataFrame({
             "time": time_ip,
@@ -320,7 +321,7 @@ def episode_single(
         df['group_id'] = df.groupby(['segment', lv1_col]).ngroup()
         group_has_lv2 = df.groupby('group_id')[lv2_col].transform(lambda x: (x > 0).any())
         return df[lv1_col].where(~group_has_lv2, 0)
-    
+
     ep_per_seg['lv1_hypo_excl'] = calculate_exclusion(ep_per_seg, 'lv1_hypo', 'lv2_hypo')
     ep_per_seg['lv1_hyper_excl'] = calculate_exclusion(ep_per_seg, 'lv1_hyper', 'lv2_hyper')
 
